@@ -29,6 +29,7 @@
 #include <QPainter>
 #include <QMenu>
 #include <QDesktopWidget>
+#include <QGraphicsDropShadowEffect>
 
 #include <KWindowSystem>
 #include <Plasma/FrameSvg>
@@ -38,12 +39,12 @@
 #include <Plasma/WindowEffects>
 #include <KApplication>
 
-MenuBar::MenuBar(QMenu *menu)
+MenuBar::MenuBar()
     : QGraphicsView(),
     m_hideTimer(new QTimer(this)),
     m_background(new Plasma::FrameSvg(this)),
     m_scene(new QGraphicsScene(this)),
-    m_container(new MenuWidget(this, menu))
+    m_container(new MenuWidget(this))
 {
     qreal left, top, right, bottom;
 
@@ -66,11 +67,21 @@ MenuBar::MenuBar(QMenu *menu)
 
     setScene(m_scene);
 
+    // Add shadow for better readability
+    if (! Plasma::WindowEffects::isEffectAvailable(Plasma::WindowEffects::BlurBehind)) {
+        QGraphicsDropShadowEffect* shadow = new QGraphicsDropShadowEffect();
+        shadow->setBlurRadius(5);
+        shadow->setOffset(QPointF(1, 1));
+        shadow->setColor(Plasma::Theme::defaultTheme()->color(Plasma::Theme::BackgroundColor));
+        setGraphicsEffect(shadow);
+    }
+
     m_background->getMargins(left, top, right, bottom);
     m_container->layout()->setContentsMargins(left, top, right, bottom);
     resize(sizeHint());
 
     connect(m_container, SIGNAL(aboutToHide()), this, SLOT(slotAboutToHide()));
+    connect(m_container, SIGNAL(needResize()), this, SIGNAL(needResize()));
     connect(m_hideTimer, SIGNAL(timeout()), this, SLOT(slotAboutToHide()));
 }
 
@@ -78,11 +89,6 @@ MenuBar::~MenuBar()
 {
 }
 
-void MenuBar::update(QMenu *menu)
-{
-    m_container->updateLayout(menu);
-}
-
 QSize MenuBar::sizeHint() const
 {
     QSizeF size = m_container->minimumSize();
