@@ -43,24 +43,22 @@ class MenuBar : public QGraphicsView
 {
 Q_OBJECT
 public:
-    MenuBar(QMenu *menu = 0);
+    MenuBar();
     ~MenuBar();
 
+    /**
+     * Set root menu
+     */
+    void setMenu(QMenu *menu) { m_container->setMenu(menu); }
     /**
      * Auto open menu items on mouse over
      */
     void autoOpen() { m_container->autoOpen(); }
-
     /**
      * Set action as active menubar action
      */
     void setActiveAction(QAction *action) { m_container->setActiveAction(action); }
 
-    /**
-     * Update menubar with menu
-     */
-    void update(QMenu *menu);
-
     virtual QSize sizeHint() const;
     virtual void show();
     virtual void hide();
@@ -68,6 +66,7 @@ public:
 private Q_SLOTS:
     void slotAboutToHide();
 Q_SIGNALS:
+    void needResize();
     void aboutToHide();
 protected:
     /**
