@@ -77,6 +77,7 @@ namespace Oxygen
     class Transitions;
     class WindowManager;
     class WidgetExplorer;
+    class BlurHelper;
 
     //! toplevel manager
     class TopLevelManager: public QObject
@@ -354,6 +355,10 @@ namespace Oxygen
         MdiWindowShadowFactory& mdiWindowShadowFactory( void ) const
         { return *_mdiWindowShadowFactory; }
 
+        //! blur helper
+        BlurHelper& blurHelper( void ) const
+        { return *_blurHelper; }
+
         //! mdi window shadows
         Mnemonics& mnemonics( void ) const
         { return *_mnemonics; }
@@ -874,6 +879,9 @@ namespace Oxygen
         //! keyboard accelerators
         Mnemonics* _mnemonics;
 
+        //! blur helper
+        BlurHelper* _blurHelper;
+
         //! widget explorer
         WidgetExplorer* _widgetExplorer;
 
