@@ -24,6 +24,7 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include "options.h"
 
 #include <kconfiggroup.h>
+#include "composite.h"
 
 namespace KWin
 {
@@ -52,7 +53,6 @@ BRIDGE_HELPER(bool, keepAbove, , , const)
 BRIDGE_HELPER(bool, keepBelow, , , const)
 BRIDGE_HELPER(bool, isMovable, , , const)
 BRIDGE_HELPER(bool, isResizable, , , const)
-BRIDGE_HELPER(QString, caption, , , const)
 BRIDGE_HELPER(void, processMousePressEvent, QMouseEvent* e, e,)
 BRIDGE_HELPER(QRect, geometry, , , const)
 BRIDGE_HELPER(void, closeWindow, , ,)
@@ -113,6 +113,22 @@ void Bridge::showWindowMenu(const QRect &p)
     c->workspace()->showWindowMenu(p, c);
 }
 
+void Bridge::showApplicationMenu(const QPoint &p)
+{
+#ifdef KWIN_BUILD_KAPPMENU
+    c->showApplicationMenu(p);
+#endif
+}
+
+bool Bridge::menuAvailable() const
+{
+#ifdef KWIN_BUILD_KAPPMENU
+    return c->menuAvailable();
+#else
+    return false;
+#endif
+}
+
 void Bridge::performWindowOperation(WindowOperation op)
 {
     c->workspace()->performWindowOperation(c, op);
@@ -215,7 +231,7 @@ void Bridge::grabXServer(bool grab)
 
 bool Bridge::compositingActive() const
 {
-    return c->workspace()->compositingActive();
+    return Compositor::compositing();
 }
 
 QRect Bridge::transparentRect() const
@@ -260,11 +276,16 @@ QIcon Bridge::icon(int idx) const
     return icon();
 }
 
+QString Bridge::caption() const
+{
+    return c->caption(true, true);
+}
+
 QString Bridge::caption(int idx) const
 {
     if (c->tabGroup())
-        return c->tabGroup()->clients().at(idx)->caption();
-    return c->caption();
+        return c->tabGroup()->clients().at(idx)->caption(true, true);
+    return c->caption(true, true);
 }
 
 long Bridge::currentTabId() const
