@@ -45,6 +45,7 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include "invert/invert_config.h"
 #include "lookingglass/lookingglass_config.h"
 #include "magnifier/magnifier_config.h"
+#include "mouseclick/mouseclick_config.h"
 #include "mousemark/mousemark_config.h"
 #include "trackmouse/trackmouse_config.h"
 #include "wobblywindows/wobblywindows_config.h"
@@ -79,6 +80,7 @@ KWIN_EFFECT_CONFIG_MULTIPLE(builtins,
                             KWIN_EFFECT_CONFIG_SINGLE(glide, GlideEffectConfig)
                             KWIN_EFFECT_CONFIG_SINGLE(invert, InvertEffectConfig)
                             KWIN_EFFECT_CONFIG_SINGLE(lookingglass, LookingGlassEffectConfig)
+                            KWIN_EFFECT_CONFIG_SINGLE(mouseclick, MouseClickEffectConfig)
                             KWIN_EFFECT_CONFIG_SINGLE(magnifier, MagnifierEffectConfig)
                             KWIN_EFFECT_CONFIG_SINGLE(mousemark, MouseMarkEffectConfig)
                             KWIN_EFFECT_CONFIG_SINGLE(trackmouse, TrackMouseEffectConfig)
