@@ -105,7 +105,7 @@ void LogoutEffect::prePaintScreen(ScreenPrePaintData& data, int time)
     } else if (!blurTexture) {
         blurSupported = false;
         delete blurTarget; // catch as we just tested the texture ;-P
-        if (effects->compositingType() == OpenGLCompositing && GLTexture::NPOTTextureSupported() && GLRenderTarget::blitSupported() && useBlur) {
+        if (effects->isOpenGLCompositing() && GLTexture::NPOTTextureSupported() && GLRenderTarget::blitSupported() && useBlur) {
             // TODO: It seems that it is not possible to create a GLRenderTarget that has
             //       a different size than the display right now. Most likely a KWin core bug.
             // Create texture and render target
@@ -143,23 +143,23 @@ void LogoutEffect::prePaintScreen(ScreenPrePaintData& data, int time)
 void LogoutEffect::paintWindow(EffectWindow* w, int mask, QRegion region, WindowPaintData& data)
 {
     if (progress > 0.0) {
-        if (effects->compositingType() == KWin::OpenGLCompositing) {
+        if (effects->isOpenGLCompositing()) {
             // In OpenGL mode we add vignetting and, if supported, a slight blur
             if (blurSupported) {
                 // When using blur we render everything to an FBO and as such don't do the vignetting
                 // until after we render the FBO to the screen.
                 if (w == logoutWindow) {
                     // Window is rendered after the FBO
-                    windowOpacity = data.opacity;
-                    data.opacity = 0.0; // Cheat, we need the opacity for later but don't want to blur it
+                    windowOpacity = data.opacity();
+                    data.setOpacity(0.0); // Cheat, we need the opacity for later but don't want to blur it
                 } else {
                     if (logoutWindowPassed || ignoredWindows.contains(w)) {
                         // Window is rendered after the FBO
                         windows.append(w);
-                        windowsOpacities[ w ] = data.opacity;
-                        data.opacity = 0.0;
+                        windowsOpacities[ w ] = data.opacity();
+                        data.setOpacity(0.0);
                     } else // Window is added to the FBO
-                        data.saturation *= (1.0 - progress * 0.2);
+                        data.multiplySaturation((1.0 - progress * 0.2));
                 }
             } else {
                 // If we are not blurring then we are not rendering to an FBO
@@ -168,15 +168,15 @@ void LogoutEffect::paintWindow(EffectWindow* w, int mask, QRegion region, Window
                     renderVignetting();
                 else if (!logoutWindowPassed && !ignoredWindows.contains(w))
                     // Window is in the background, desaturate
-                    data.saturation *= (1.0 - progress * 0.2);
+                    data.multiplySaturation((1.0 - progress * 0.2));
                 // All other windows are unaltered
             }
         }
         if (effects->compositingType() == KWin::XRenderCompositing) {
             // Since we can't do vignetting in XRender just do a stronger desaturation and darken
             if (w != logoutWindow && !logoutWindowPassed && !ignoredWindows.contains(w)) {
-                data.saturation *= (1.0 - progress * 0.8);
-                data.brightness *= (1.0 - progress * 0.3);
+                data.multiplySaturation((1.0 - progress * 0.8));
+                data.multiplyBrightness((1.0 - progress * 0.3));
             }
         }
         if (w == logoutWindow ||
@@ -192,7 +192,7 @@ void LogoutEffect::paintScreen(int mask, QRegion region, ScreenPaintData& data)
 {
     effects->paintScreen(mask, region, data);
 
-    if (effects->compositingType() == KWin::OpenGLCompositing && progress > 0.0) {
+    if (effects->isOpenGLCompositing() && progress > 0.0) {
         if (!blurSupported) {
             if (!logoutWindowPassed)
                 // The logout window has been deleted but we still want to fade out the vignetting, thus
@@ -216,7 +216,7 @@ void LogoutEffect::paintScreen(int mask, QRegion region, ScreenPaintData& data)
             if (logoutWindow) {
                 int winMask = logoutWindow->hasAlpha() ? PAINT_WINDOW_TRANSLUCENT : PAINT_WINDOW_OPAQUE;
                 WindowPaintData winData(logoutWindow);
-                winData.opacity = windowOpacity;
+                winData.setOpacity(windowOpacity);
                 effects->drawWindow(logoutWindow, winMask, region, winData);
             }
 
@@ -224,7 +224,7 @@ void LogoutEffect::paintScreen(int mask, QRegion region, ScreenPaintData& data)
             foreach (EffectWindow * w, windows) {
                 int winMask = w->hasAlpha() ? PAINT_WINDOW_TRANSLUCENT : PAINT_WINDOW_OPAQUE;
                 WindowPaintData winData(w);
-                winData.opacity = windowsOpacities[ w ];
+                winData.setOpacity(windowsOpacities[ w ]);
                 effects->drawWindow(w, winMask, region, winData);
             }
 
@@ -288,7 +288,7 @@ bool LogoutEffect::isLogoutDialog(EffectWindow* w)
 
 void LogoutEffect::renderVignetting()
 {
-    if (!ShaderManager::instance()->isValid()) {
+    if (effects->compositingType() == OpenGL1Compositing) {
         renderVignettingLegacy();
         return;
     }
@@ -307,7 +307,7 @@ void LogoutEffect::renderVignetting()
     QMatrix4x4 projection = ShaderManager::instance()->pushShader(KWin::ShaderManager::SimpleShader)->getUniformMatrix4x4("projection");
     ShaderManager::instance()->popShader();
 
-    ShaderManager::instance()->pushShader(m_vignettingShader);
+    ShaderBinder binder(m_vignettingShader);
     m_vignettingShader->setUniform(KWin::GLShader::ProjectionMatrix, projection);
     m_vignettingShader->setUniform("u_progress", (float)progress * 0.9f);
     glEnable(GL_BLEND);
@@ -335,12 +335,11 @@ void LogoutEffect::renderVignetting()
     }
     glDisable(GL_SCISSOR_TEST);
     glDisable(GL_BLEND);
-    ShaderManager::instance()->popShader();
 }
 
 void LogoutEffect::renderVignettingLegacy()
 {
-#ifndef KWIN_HAVE_OPENGLES
+#ifdef KWIN_HAVE_OPENGL_1
     glPushAttrib(GL_CURRENT_BIT | GL_ENABLE_BIT | GL_TEXTURE_BIT);
     glEnable(GL_BLEND);   // If not already (Such as when rendered straight to the screen)
     glBlendFunc(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
@@ -369,7 +368,7 @@ void LogoutEffect::renderVignettingLegacy()
 
 void LogoutEffect::renderBlurTexture()
 {
-    if (!ShaderManager::instance()->isValid()) {
+    if (effects->compositingType() == OpenGL1Compositing) {
         renderBlurTextureLegacy();
         return;
     }
@@ -384,11 +383,10 @@ void LogoutEffect::renderBlurTexture()
         return;
     }
     // Unmodified base image
-    ShaderManager::instance()->pushShader(m_blurShader);
+    ShaderBinder binder(m_blurShader);
     m_blurShader->setUniform(GLShader::Offset, QVector2D(0, 0));
     m_blurShader->setUniform(GLShader::ModulationConstant, QVector4D(1.0, 1.0, 1.0, 1.0));
     m_blurShader->setUniform(GLShader::Saturation, 1.0);
-    m_blurShader->setUniform(GLShader::AlphaToOne, 1);
     m_blurShader->setUniform("u_alphaProgress", (float)progress * 0.4f);
     glEnable(GL_BLEND);
     glBlendFunc(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
@@ -396,13 +394,12 @@ void LogoutEffect::renderBlurTexture()
     blurTexture->render(infiniteRegion(), QRect(0, 0, displayWidth(), displayHeight()));
     blurTexture->unbind();
     glDisable(GL_BLEND);
-    ShaderManager::instance()->popShader();
     checkGLError("Render blur texture");
 }
 
 void LogoutEffect::renderBlurTextureLegacy()
 {
-#ifndef KWIN_HAVE_OPENGLES
+#ifdef KWIN_HAVE_OPENGL_1
     glPushAttrib(GL_CURRENT_BIT | GL_ENABLE_BIT | GL_TEXTURE_BIT);
     // Unmodified base image
     blurTexture->bind();
