@@ -63,12 +63,12 @@ void LanczosFilter::init()
     if (!force && options->glSmoothScale() != 2)
         return; // disabled by config
 
-    // The lanczos filter is reported to be broken with the Intel driver and Mesa 7.10
+    // The lanczos filter is reported to be broken with the Intel driver prior SandyBridge
     GLPlatform *gl = GLPlatform::instance();
-    if (!force && gl->driver() == Driver_Intel && gl->mesaVersion() >= kVersionNumber(7, 10) && gl->chipClass() < SandyBridge)
+    if (!force && gl->driver() == Driver_Intel && gl->chipClass() < SandyBridge)
         return;
-    // With fglrx the ARB Shader crashes KWin (see Bug #270818 and #286795) and GLSL Shaders are not functional
-    if (!force && gl->driver() == Driver_Catalyst) {
+    // With fglrx the ARB Shader crashes KWin (see Bug #270818 and #286795)
+    if (!force && gl->driver() == Driver_Catalyst && effects->compositingType() == OpenGL1Compositing) {
         return;
     }
 
@@ -158,7 +158,7 @@ void LanczosShader::createOffsets(int count, float width, Qt::Orientation direct
 
 void LanczosFilter::performPaint(EffectWindowImpl* w, int mask, QRegion region, WindowPaintData& data)
 {
-    if (effects->compositingType() == KWin::OpenGLCompositing && (data.xScale < 0.9 || data.yScale < 0.9) &&
+    if (effects->isOpenGLCompositing() && (data.xScale() < 0.9 || data.yScale() < 0.9) &&
             KGlobalSettings::graphicEffectsLevel() & KGlobalSettings::SimpleAnimationEffects) {
         if (!m_inited)
             init();
@@ -186,10 +186,10 @@ void LanczosFilter::performPaint(EffectWindowImpl* w, int mask, QRegion region,
                 width = w->width();
                 height = w->height();
             }
-            int tx = data.xTranslate + w->x() + left * data.xScale;
-            int ty = data.yTranslate + w->y() + top * data.yScale;
-            int tw = width * data.xScale;
-            int th = height * data.yScale;
+            int tx = data.xTranslation() + w->x() + left * data.xScale();
+            int ty = data.yTranslation() + w->y() + top * data.yScale();
+            int tw = width * data.xScale();
+            int th = height * data.yScale();
             const QRect textureRect(tx, ty, tw, th);
             const bool hardwareClipping = !(QRegion(textureRect)-region).isEmpty();
 
@@ -203,27 +203,26 @@ void LanczosFilter::performPaint(EffectWindowImpl* w, int mask, QRegion region,
                     if (hardwareClipping) {
                         glEnable(GL_SCISSOR_TEST);
                     }
-                    if (ShaderManager::instance()->isValid()) {
+                    if (effects->compositingType() == OpenGL2Compositing) {
                         glEnable(GL_BLEND);
                         glBlendFunc(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
 
-                        const float rgb = data.brightness * data.opacity;
-                        const float a = data.opacity;
+                        const qreal rgb = data.brightness() * data.opacity();
+                        const qreal a = data.opacity();
 
-                        GLShader *shader = ShaderManager::instance()->pushShader(ShaderManager::SimpleShader);
+                        ShaderBinder binder(ShaderManager::SimpleShader);
+                        GLShader *shader = binder.shader();
                         shader->setUniform(GLShader::Offset, QVector2D(0, 0));
                         shader->setUniform(GLShader::ModulationConstant, QVector4D(rgb, rgb, rgb, a));
-                        shader->setUniform(GLShader::Saturation, data.saturation);
-                        shader->setUniform(GLShader::AlphaToOne, 0);
+                        shader->setUniform(GLShader::Saturation, data.saturation());
 
                         cachedTexture->render(region, textureRect, hardwareClipping);
 
-                        ShaderManager::instance()->popShader();
                         glDisable(GL_BLEND);
                     } else {
-                        prepareRenderStates(cachedTexture, data.opacity, data.brightness, data.saturation);
+                        prepareRenderStates(cachedTexture, data.opacity(), data.brightness(), data.saturation());
                         cachedTexture->render(region, textureRect, hardwareClipping);
-                        restoreRenderStates(cachedTexture, data.opacity, data.brightness, data.saturation);
+                        restoreRenderStates(cachedTexture, data.opacity(), data.brightness(), data.saturation());
                     }
                     if (hardwareClipping) {
                         glDisable(GL_SCISSOR_TEST);
@@ -240,13 +239,13 @@ void LanczosFilter::performPaint(EffectWindowImpl* w, int mask, QRegion region,
             }
 
             WindowPaintData thumbData = data;
-            thumbData.xScale = 1.0;
-            thumbData.yScale = 1.0;
-            thumbData.xTranslate = -w->x() - left;
-            thumbData.yTranslate = -w->y() - top;
-            thumbData.brightness = 1.0;
-            thumbData.opacity = 1.0;
-            thumbData.saturation = 1.0;
+            thumbData.setXScale(1.0);
+            thumbData.setYScale(1.0);
+            thumbData.setXTranslation(-w->x() - left);
+            thumbData.setYTranslation(-w->y() - top);
+            thumbData.setBrightness(1.0);
+            thumbData.setOpacity(1.0);
+            thumbData.setSaturation(1.0);
 
             // Bind the offscreen FBO and draw the window on it unscaled
             updateOffscreenSurfaces();
@@ -340,27 +339,26 @@ void LanczosFilter::performPaint(EffectWindowImpl* w, int mask, QRegion region,
             if (hardwareClipping) {
                 glEnable(GL_SCISSOR_TEST);
             }
-            if (ShaderManager::instance()->isValid()) {
+            if (effects->compositingType() == OpenGL2Compositing) {
                 glEnable(GL_BLEND);
                 glBlendFunc(GL_SRC_ALPHA, GL_ONE_MINUS_SRC_ALPHA);
 
-                const float rgb = data.brightness * data.opacity;
-                const float a = data.opacity;
+                const qreal rgb = data.brightness() * data.opacity();
+                const qreal a = data.opacity();
 
-                GLShader *shader = ShaderManager::instance()->pushShader(ShaderManager::SimpleShader);
+                ShaderBinder binder(ShaderManager::SimpleShader);
+                GLShader *shader = binder.shader();
                 shader->setUniform(GLShader::Offset, QVector2D(0, 0));
                 shader->setUniform(GLShader::ModulationConstant, QVector4D(rgb, rgb, rgb, a));
-                shader->setUniform(GLShader::Saturation, data.saturation);
-                shader->setUniform(GLShader::AlphaToOne, 0);
+                shader->setUniform(GLShader::Saturation, data.saturation());
 
                 cache->render(region, textureRect, hardwareClipping);
 
-                ShaderManager::instance()->popShader();
                 glDisable(GL_BLEND);
             } else {
-                prepareRenderStates(cache, data.opacity, data.brightness, data.saturation);
+                prepareRenderStates(cache, data.opacity(), data.brightness(), data.saturation());
                 cache->render(region, textureRect, hardwareClipping);
-                restoreRenderStates(cache, data.opacity, data.brightness, data.saturation);
+                restoreRenderStates(cache, data.opacity(), data.brightness(), data.saturation());
             }
             if (hardwareClipping) {
                 glDisable(GL_SCISSOR_TEST);
@@ -400,7 +398,7 @@ void LanczosFilter::timerEvent(QTimerEvent *event)
 
 void LanczosFilter::prepareRenderStates(GLTexture* tex, double opacity, double brightness, double saturation)
 {
-#ifdef KWIN_HAVE_OPENGLES
+#ifndef KWIN_HAVE_OPENGL_1
     Q_UNUSED(tex)
     Q_UNUSED(opacity)
     Q_UNUSED(brightness)
@@ -432,7 +430,8 @@ void LanczosFilter::prepareRenderStates(GLTexture* tex, double opacity, double b
         // Note that both operands have to be in range [0.5; 1] since opengl
         //  automatically substracts 0.5 from them
         glActiveTexture(GL_TEXTURE1);
-        float saturation_constant[] = { 0.5 + 0.5 * 0.30, 0.5 + 0.5 * 0.59, 0.5 + 0.5 * 0.11, saturation };
+        float saturation_constant[] = { 0.5 + 0.5 * 0.30, 0.5 + 0.5 * 0.59, 0.5 + 0.5 * 0.11,
+                                        static_cast<float>(saturation) };
         glTexEnvi(GL_TEXTURE_ENV, GL_TEXTURE_ENV_MODE, GL_COMBINE);
         glTexEnvi(GL_TEXTURE_ENV, GL_COMBINE_RGB, GL_DOT3_RGB);
         glTexEnvi(GL_TEXTURE_ENV, GL_SOURCE0_RGB, GL_PREVIOUS);
@@ -500,7 +499,8 @@ void LanczosFilter::prepareRenderStates(GLTexture* tex, double opacity, double b
                       opacity);
         } else {
             // Multiply color by brightness and replace alpha by opacity
-            float constant[] = { opacityByBrightness, opacityByBrightness, opacityByBrightness, opacity };
+            float constant[] = { opacityByBrightness, opacityByBrightness, opacityByBrightness,
+                                 static_cast<float>(opacity) };
             glTexEnvi(GL_TEXTURE_ENV, GL_TEXTURE_ENV_MODE, GL_COMBINE);
             glTexEnvi(GL_TEXTURE_ENV, GL_COMBINE_RGB, GL_MODULATE);
             glTexEnvi(GL_TEXTURE_ENV, GL_SOURCE0_RGB, GL_TEXTURE);
@@ -517,7 +517,7 @@ void LanczosFilter::prepareRenderStates(GLTexture* tex, double opacity, double b
 
 void LanczosFilter::restoreRenderStates(GLTexture* tex, double opacity, double brightness, double saturation)
 {
-#ifdef KWIN_HAVE_OPENGLES
+#ifndef KWIN_HAVE_OPENGL_1
     Q_UNUSED(tex)
     Q_UNUSED(opacity)
     Q_UNUSED(brightness)
@@ -557,7 +557,7 @@ LanczosShader::LanczosShader(QObject* parent)
 LanczosShader::~LanczosShader()
 {
     delete m_shader;
-#ifndef KWIN_HAVE_OPENGLES
+#ifdef KWIN_HAVE_OPENGL_1
     if (m_arbProgram) {
         glDeleteProgramsARB(1, &m_arbProgram);
         m_arbProgram = 0;
@@ -569,7 +569,7 @@ void LanczosShader::bind()
 {
     if (m_shader)
         ShaderManager::instance()->pushShader(m_shader);
-#ifndef KWIN_HAVE_OPENGLES
+#ifdef KWIN_HAVE_OPENGL_1
     else {
         glEnable(GL_FRAGMENT_PROGRAM_ARB);
         glBindProgramARB(GL_FRAGMENT_PROGRAM_ARB, m_arbProgram);
@@ -581,7 +581,7 @@ void LanczosShader::unbind()
 {
     if (m_shader)
         ShaderManager::instance()->popShader();
-#ifndef KWIN_HAVE_OPENGLES
+#ifdef KWIN_HAVE_OPENGL_1
     else {
         int boundObject;
         glGetProgramivARB(GL_FRAGMENT_PROGRAM_ARB, GL_PROGRAM_BINDING_ARB, &boundObject);
@@ -600,7 +600,7 @@ void LanczosShader::setUniforms()
         glUniform2fv(m_uOffsets, 16, (const GLfloat*)m_offsets);
         glUniform4fv(m_uKernel, 16, (const GLfloat*)m_kernel);
     }
-#ifndef KWIN_HAVE_OPENGLES
+#ifdef KWIN_HAVE_OPENGL_1
     else {
         for (int i = 0; i < 16; ++i) {
             glProgramLocalParameter4fARB(GL_FRAGMENT_PROGRAM_ARB, i, m_offsets[i].x(), m_offsets[i].y(), 0, 0);
@@ -616,16 +616,15 @@ bool LanczosShader::init()
 {
     GLPlatform *gl = GLPlatform::instance();
     if (gl->supports(GLSL) &&
-            ShaderManager::instance()->isValid() &&
+            effects->compositingType() == OpenGL2Compositing &&
             GLRenderTarget::supported() &&
             !(gl->isRadeon() && gl->chipClass() < R600)) {
         m_shader = ShaderManager::instance()->loadFragmentShader(ShaderManager::SimpleShader, ":/resources/lanczos-fragment.glsl");
         if (m_shader->isValid()) {
-            ShaderManager::instance()->pushShader(m_shader);
+            ShaderBinder binder(m_shader);
             m_uTexUnit    = m_shader->uniformLocation("texUnit");
             m_uKernel     = m_shader->uniformLocation("kernel");
             m_uOffsets    = m_shader->uniformLocation("offsets");
-            ShaderManager::instance()->popShader();
             return true;
         } else {
             kDebug(1212) << "Shader is not valid";
@@ -634,7 +633,7 @@ bool LanczosShader::init()
         }
     }
 
-#ifdef KWIN_HAVE_OPENGLES
+#ifndef KWIN_HAVE_OPENGL_1
     // no ARB shader in GLES
     return false;
 #else
