@@ -21,10 +21,13 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include "kwinanimationeffect.h"
 #include "anidata_p.h"
 
-#include <QTime>
+#include <QDateTime>
 #include <QTimer>
 
 namespace KWin {
+
+QElapsedTimer AnimationEffect::s_clock;
+
 struct AnimationEffectPrivate {
 public:
     AnimationEffectPrivate() { m_animated = m_damageDirty = false; }
@@ -40,6 +43,8 @@ AnimationEffect::AnimationEffect() : d_ptr(new AnimationEffectPrivate())
 {
     Q_D(AnimationEffect);
     d->m_animated = false;
+    if (!s_clock.isValid())
+        s_clock.start();
     /* this is the same as the QTimer::singleShot(0, SLOT(init())) kludge
      * defering the init and esp. the connection to the windowClosed slot */
     QMetaObject::invokeMethod( this, "init", Qt::QueuedConnection );
@@ -66,7 +71,8 @@ bool AnimationEffect::isActive() const
 }
 
 
-#define RELATIVE_XY(_FIELD_) const bool relative[2] = { metaData(Relative##_FIELD_##X, meta), metaData(Relative##_FIELD_##Y, meta) }
+#define RELATIVE_XY(_FIELD_) const bool relative[2] = { static_cast<bool>(metaData(Relative##_FIELD_##X, meta)), \
+                                                        static_cast<bool>(metaData(Relative##_FIELD_##Y, meta)) }
 
 void AnimationEffect::animate( EffectWindow *w, Attribute a, uint meta, int ms, FPx2 to, QEasingCurve curve, int delay, FPx2 from )
 {
@@ -201,7 +207,7 @@ void AnimationEffect::prePaintScreen( ScreenPrePaintData& data, int time )
         bool invalidateLayerRect = false;
         QList<AniData>::iterator anim = entry->first.begin(), animEnd = entry->first.end();
         while (anim != animEnd) {
-            if (QTime::currentTime() < anim->startTime) {
+            if (anim->startTime > clock()) {
                 if (!anim->waitAtSource) {
                     ++anim;
                     continue;
@@ -346,7 +352,7 @@ void AnimationEffect::prePaintWindow( EffectWindow* w, WindowPrePaintData& data,
         if ( entry != d->m_animations.constEnd() ) {
             bool isUsed = false;
             for (QList<AniData>::const_iterator anim = entry->first.constBegin(); anim != entry->first.constEnd(); ++anim) {
-                if (QTime::currentTime() < anim->startTime && !anim->waitAtSource)
+                if (anim->startTime > clock() && !anim->waitAtSource)
                     continue;
 
                 isUsed = true;
@@ -391,24 +397,24 @@ void AnimationEffect::paintWindow( EffectWindow* w, int mask, QRegion region, Wi
         if ( entry != d->m_animations.constEnd() ) {
             for ( QList<AniData>::const_iterator anim = entry->first.constBegin(); anim != entry->first.constEnd(); ++anim ) {
 
-                if (QTime::currentTime() < anim->startTime && !anim->waitAtSource)
+                if (anim->startTime > clock() && !anim->waitAtSource)
                     continue;
 
                 switch (anim->attribute) {
                 case Opacity:
-                    data.opacity *= interpolated(*anim); break;
+                    data.multiplyOpacity(interpolated(*anim)); break;
                 case Brightness:
-                    data.brightness *= interpolated(*anim); break;
+                    data.multiplyBrightness(interpolated(*anim)); break;
                 case Saturation:
-                    data.saturation *= interpolated(*anim); break;
+                    data.multiplySaturation(interpolated(*anim)); break;
                 case Scale: {
                     const QSize sz = w->geometry().size();
                     float f1(1.0), f2(0.0);
                     if (anim->from[0] >= 0.0 && anim->to[0] >= 0.0) { // scale x
                         f1 = interpolated(*anim, 0);
                         f2 = geometryCompensation( anim->meta & AnimationEffect::Horizontal, f1 );
-                        data.xTranslate += f2 * sz.width();
-                        data.xScale *= f1;
+                        data.translate(f2 * sz.width());
+                        data.setXScale(data.xScale() * f1);
                     }
                     if (anim->from[1] >= 0.0 && anim->to[1] >= 0.0) { // scale y
                         if (!anim->isOneDimensional()) {
@@ -417,8 +423,8 @@ void AnimationEffect::paintWindow( EffectWindow* w, int mask, QRegion region, Wi
                         }
                         else if ( ((anim->meta & AnimationEffect::Vertical)>>1) != (anim->meta & AnimationEffect::Horizontal) )
                             f2 = geometryCompensation( anim->meta & AnimationEffect::Vertical, f1 );
-                        data.yTranslate += f2 * sz.height();
-                        data.yScale *= f1;
+                        data.translate(0.0, f2 * sz.height());
+                        data.setYScale(data.yScale() * f1);
                     }
                     break;
                 }
@@ -426,8 +432,7 @@ void AnimationEffect::paintWindow( EffectWindow* w, int mask, QRegion region, Wi
                     region = clipRect(w->expandedGeometry(), *anim);
                     break;
                 case Translation:
-                    data.xTranslate += interpolated(*anim, 0);
-                    data.yTranslate += interpolated(*anim, 1);
+                    data += QPointF(interpolated(*anim, 0), interpolated(*anim, 1));
                     break;
                 case Size: {
                     FPx2 dest = anim->from + progress(*anim) * (anim->to - anim->from);
@@ -435,13 +440,13 @@ void AnimationEffect::paintWindow( EffectWindow* w, int mask, QRegion region, Wi
                     float f;
                     if (anim->from[0] >= 0.0 && anim->to[0] >= 0.0) { // resize x
                         f = dest[0]/sz.width();
-                        data.xTranslate += geometryCompensation( anim->meta & AnimationEffect::Horizontal, f ) * sz.width();
-                        data.xScale *= f;
+                        data.translate(geometryCompensation( anim->meta & AnimationEffect::Horizontal, f ) * sz.width());
+                        data.setXScale(data.xScale() * f);
                     }
                     if (anim->from[1] >= 0.0 && anim->to[1] >= 0.0) { // resize y
                         f = dest[1]/sz.height();
-                        data.yTranslate += geometryCompensation( anim->meta & AnimationEffect::Vertical, f ) * sz.height();
-                        data.yScale *= f;
+                        data.translate(0.0, geometryCompensation( anim->meta & AnimationEffect::Vertical, f ) * sz.height());
+                        data.setYScale(data.yScale() * f);
                     }
                     break;
                 }
@@ -452,21 +457,20 @@ void AnimationEffect::paintWindow( EffectWindow* w, int mask, QRegion region, Wi
                         float dest = interpolated(*anim, 0);
                         const int x[2] = {  xCoord(geo, metaData(SourceAnchor, anim->meta)),
                                             xCoord(geo, metaData(TargetAnchor, anim->meta)) };
-                        data.xTranslate += dest - (x[0] + prgrs*(x[1] - x[0]));
+                        data.translate(dest - (x[0] + prgrs*(x[1] - x[0])));
                     }
                     if ( anim->from[1] >= 0.0 && anim->to[1] >= 0.0 ) {
                         float dest = interpolated(*anim, 1);
                         const int y[2] = {  yCoord(geo, metaData(SourceAnchor, anim->meta)),
                                             yCoord(geo, metaData(TargetAnchor, anim->meta)) };
-                        data.yTranslate += dest - (y[0] + prgrs*(y[1] - y[0]));
+                        data.translate(0.0, dest - (y[0] + prgrs*(y[1] - y[0])));
                     }
                     break;
                 }
                 case Rotation: {
-                    RotationData rot;
-                    rot.axis = (RotationData::RotationAxis)metaData(Axis, anim->meta);
+                    data.setRotationAxis((Qt::Axis)metaData(Axis, anim->meta));
                     const float prgrs = progress(*anim);
-                    rot.angle = anim->from[0] + prgrs*(anim->to[0] - anim->from[0]);
+                    data.setRotationAngle(anim->from[0] + prgrs*(anim->to[0] - anim->from[0]));
 
                     const QRect geo = w->rect();
                     const uint  sAnchor = metaData(SourceAnchor, anim->meta),
@@ -477,10 +481,7 @@ void AnimationEffect::paintWindow( EffectWindow* w, int mask, QRegion region, Wi
                         QPointF pt2(xCoord(geo, tAnchor), yCoord(geo, tAnchor));
                         pt += static_cast<qreal>(prgrs)*(pt2 - pt);
                     }
-
-                    rot.xRotationPoint = pt.x();
-                    rot.yRotationPoint = pt.y();
-                    data.rotation = &rot;
+                    data.setRotationOrigin(QVector3D(pt));
                     break;
                 }
                 case Generic:
@@ -515,14 +516,14 @@ void AnimationEffect::postPaintScreen()
 
 float AnimationEffect::interpolated( const AniData &a, int i ) const
 {
-    if (QTime::currentTime() < a.startTime)
+    if (a.startTime > clock())
         return a.from[i];
     return a.from[i] + a.curve.valueForProgress( ((float)a.time)/a.duration )*(a.to[i] - a.from[i]);
 }
 
 float AnimationEffect::progress( const AniData &a ) const
 {
-    if (QTime::currentTime() < a.startTime)
+    if (a.startTime > clock())
         return 0.0;
     return a.curve.valueForProgress( ((float)a.time)/a.duration );
 }
@@ -634,7 +635,7 @@ void AnimationEffect::updateLayerRepaints()
         QList<QRect> rects;
         QRect *layerRect = const_cast<QRect*>(&(entry->second));
         for (QList<AniData>::const_iterator anim = entry->first.constBegin(), animEnd = entry->first.constEnd(); anim != animEnd; ++anim) {
-            if (QTime::currentTime() < anim->startTime)
+            if (anim->startTime > clock())
                 continue;
             switch (anim->attribute) {
                 case Opacity:
