@@ -28,6 +28,7 @@ along with this program.  If not, see <http://www.gnu.org/licenses/>.
 #include <ktoolinvocation.h>
 
 #ifndef KCMRULES
+#include <QDesktopWidget>
 #include "client.h"
 #include "workspace.h"
 #endif
@@ -50,9 +51,9 @@ Rules::Rules()
     , maxsizerule(UnusedForceRule)
     , opacityactiverule(UnusedForceRule)
     , opacityinactiverule(UnusedForceRule)
-    , tilingoptionrule(UnusedForceRule)
     , ignorepositionrule(UnusedForceRule)
     , desktoprule(UnusedSetRule)
+    , screenrule(UnusedSetRule)
     , activityrule(UnusedSetRule)
     , typerule(UnusedForceRule)
     , maximizevertrule(UnusedSetRule)
@@ -156,9 +157,9 @@ void Rules::readFromCfg(const KConfigGroup& cfg)
     READ_FORCE_RULE(opacityinactive, , 0);
     if (opacityinactive < 0 || opacityinactive > 100)
         opacityinactive = 100;
-    READ_FORCE_RULE(tilingoption, , 0);
     READ_FORCE_RULE(ignoreposition, , false);
     READ_SET_RULE(desktop, , 0);
+    READ_SET_RULE(screen, , 0);
     READ_SET_RULE(activity, , QString());
     type = readType(cfg, "type");
     typerule = type != NET::Unknown ? readForceRule(cfg, "typerule") : UnusedForceRule;
@@ -246,9 +247,9 @@ void Rules::write(KConfigGroup& cfg) const
     WRITE_FORCE_RULE(maxsize,);
     WRITE_FORCE_RULE(opacityactive,);
     WRITE_FORCE_RULE(opacityinactive,);
-    WRITE_FORCE_RULE(tilingoption,);
     WRITE_FORCE_RULE(ignoreposition,);
     WRITE_SET_RULE(desktop,);
+    WRITE_SET_RULE(screen,);
     WRITE_SET_RULE(activity,);
     WRITE_FORCE_RULE(type, int);
     WRITE_SET_RULE(maximizevert,);
@@ -288,9 +289,9 @@ bool Rules::isEmpty() const
            && maxsizerule == UnusedForceRule
            && opacityactiverule == UnusedForceRule
            && opacityinactiverule == UnusedForceRule
-           && tilingoptionrule == UnusedForceRule
            && ignorepositionrule == UnusedForceRule
            && desktoprule == UnusedSetRule
+           && screenrule == UnusedSetRule
            && activityrule == UnusedSetRule
            && typerule == UnusedForceRule
            && maximizevertrule == UnusedSetRule
@@ -463,6 +464,10 @@ bool Rules::update(Client* c, int selection)
         updated = updated || desktop != c->desktop();
         desktop = c->desktop();
     }
+    if NOW_REMEMBER(Screen, screen) {
+        updated = updated || screen != c->screen();
+        screen = c->screen();
+    }
     if NOW_REMEMBER(Activity, activity) {
         // TODO: ivan - multiple activities support
         const QString & joinedActivities = c->activities().join(",");
@@ -577,7 +582,6 @@ APPLY_FORCE_RULE(maxsize, MaxSize, QSize)
 APPLY_FORCE_RULE(opacityactive, OpacityActive, int)
 APPLY_FORCE_RULE(opacityinactive, OpacityInactive, int)
 APPLY_FORCE_RULE(ignoreposition, IgnorePosition, bool)
-APPLY_FORCE_RULE(tilingoption, TilingOption, int)
 
 // the cfg. entry needs to stay named the say for backwards compatibility
 bool Rules::applyIgnoreGeometry(bool& ignore) const
@@ -586,6 +590,7 @@ bool Rules::applyIgnoreGeometry(bool& ignore) const
 }
 
 APPLY_RULE(desktop, Desktop, int)
+APPLY_RULE(screen, Screen, int)
 APPLY_RULE(activity, Activity, QString)
 APPLY_FORCE_RULE(type, Type, NET::WindowType)
 
@@ -674,9 +679,9 @@ void Rules::discardUsed(bool withdrawn)
     DISCARD_USED_FORCE_RULE(maxsize);
     DISCARD_USED_FORCE_RULE(opacityactive);
     DISCARD_USED_FORCE_RULE(opacityinactive);
-    DISCARD_USED_FORCE_RULE(tilingoption);
     DISCARD_USED_FORCE_RULE(ignoreposition);
     DISCARD_USED_SET_RULE(desktop);
+    DISCARD_USED_SET_RULE(screen);
     DISCARD_USED_SET_RULE(activity);
     DISCARD_USED_FORCE_RULE(type);
     DISCARD_USED_SET_RULE(maximizevert);
@@ -784,7 +789,6 @@ CHECK_FORCE_RULE(MinSize, QSize)
 CHECK_FORCE_RULE(MaxSize, QSize)
 CHECK_FORCE_RULE(OpacityActive, int)
 CHECK_FORCE_RULE(OpacityInactive, int)
-CHECK_FORCE_RULE(TilingOption, int)
 CHECK_FORCE_RULE(IgnorePosition, bool)
 
 bool WindowRules::checkIgnoreGeometry(bool ignore) const
@@ -805,6 +809,20 @@ KDecorationDefines::MaximizeMode WindowRules::checkMaximize(MaximizeMode mode, b
     return static_cast< MaximizeMode >((vert ? MaximizeVertical : 0) | (horiz ? MaximizeHorizontal : 0));
 }
 
+int WindowRules::checkScreen(int screen, bool init) const
+{
+    if ( rules.count() == 0 )
+        return screen;
+    int ret = screen;
+    for ( QVector< Rules* >::ConstIterator it = rules.constBegin(); it != rules.constEnd(); ++it ) {
+        if ( (*it)->applyScreen( ret, init ))
+            break;
+    }
+    if (ret >= QApplication::desktop()->screenCount())
+        ret = screen;
+    return ret;
+}
+
 CHECK_RULE(Minimize, bool)
 CHECK_RULE(Shade, ShadeMode)
 CHECK_RULE(SkipTaskbar, bool)
@@ -850,6 +868,7 @@ void Client::applyWindowRules()
     // MinSize, MaxSize handled by Geometry
     // IgnorePosition
     setDesktop(desktop());
+    workspace()->sendClientToScreen(this, screen());
     setOnActivities(activities());
     // Type
     maximize(maximizeMode());
@@ -946,7 +965,7 @@ void Workspace::loadWindowRules()
         delete rules.front();
         rules.pop_front();
     }
-    KConfig cfg("kwinrulesrc", KConfig::NoGlobals);
+    KConfig cfg(QLatin1String(KWIN_NAME) + "rulesrc", KConfig::NoGlobals);
     int count = cfg.group("General").readEntry("count", 0);
     for (int i = 1;
             i <= count;
@@ -960,7 +979,7 @@ void Workspace::loadWindowRules()
 void Workspace::writeWindowRules()
 {
     rulesUpdatedTimer.stop();
-    KConfig cfg("kwinrulesrc", KConfig::NoGlobals);
+    KConfig cfg(QLatin1String(KWIN_NAME) + "rulesrc", KConfig::NoGlobals);
     QStringList groups = cfg.groupList();
     for (QStringList::ConstIterator it = groups.constBegin();
             it != groups.constEnd();
