@@ -147,8 +147,6 @@ Workspace::Workspace(bool restore)
     , set_active_client_recursion(0)
     , block_stacking_updates(0)
     , forced_global_mouse_grab(false)
-    , transSlider(NULL)
-    , transButton(NULL)
     , m_scripting(NULL)
 {
     // If KWin was already running it saved its configuration after loosing the selection -> Reread
