@@ -1,5 +1,6 @@
 /***************************************************************************
  *   Copyright (C) 2007 by Daniel Laidig <d.laidig@gmx.de>                 *
+ *   Copyright (C) 2012 by Luís Gabriel Lima <lampih@gmail.com>            *
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
@@ -22,14 +23,13 @@
 
 #include <QGraphicsSceneHoverEvent>
 #include <QList>
-#include <QWeakPointer>
 
 #include <Plasma/Applet>
-#include <Plasma/DataEngine>
+
+#include "model.h"
 #include "ui_pagerConfig.h"
 
 class QDesktopWidget;
-class QPropertyAnimation;
 
 class KColorScheme;
 class KWindowInfo;
@@ -37,42 +37,52 @@ class KCModuleProxy;
 
 namespace Plasma
 {
+    class DeclarativeWidget;
     class FrameSvg;
 }
 
-class DesktopRectangle : public QObject
-{
-    Q_OBJECT
-    Q_PROPERTY(qreal alphaValue READ alphaValue WRITE setAlphaValue)
-
-    public:
-        DesktopRectangle(QObject *parent);
-
-        QPropertyAnimation *animation() const;
-        void setAnimation(QPropertyAnimation *animation);
-
-        qreal alphaValue() const;
-
-    protected slots:
-        void setAlphaValue(qreal value);
-
-    private:
-        QWeakPointer<QPropertyAnimation> m_animation;
-        qreal m_alpha;
-};
-
 class Pager : public Plasma::Applet
 {
     Q_OBJECT
+    Q_PROPERTY(QObject* model READ model CONSTANT)
+    Q_PROPERTY(QVariantMap style READ style NOTIFY styleChanged)
+    Q_PROPERTY(int currentDesktop READ currentDesktop NOTIFY currentDesktopChanged)
+    Q_PROPERTY(bool showWindowIcons READ showWindowIcons NOTIFY showWindowIconsChanged)
+    Q_PROPERTY(bool showDesktopName READ showDesktopName NOTIFY showDesktopTextChanged)
+    Q_PROPERTY(bool showDesktopNumber READ showDesktopNumber NOTIFY showDesktopTextChanged)
+
     public:
         Pager(QObject *parent, const QVariantList &args);
         ~Pager();
+
         void init();
-        void paintInterface(QPainter *painter, const QStyleOptionGraphicsItem *option,
-                            const QRect &contents);
         void constraintsEvent(Plasma::Constraints);
         virtual QList<QAction*> contextualActions();
 
+        QObject *model() const { return m_pagerModel; }
+
+        QVariantMap style() const { return m_pagerStyle; }
+
+        int currentDesktop() const { return m_currentDesktop; }
+        void setCurrentDesktop(int desktop);
+
+        bool showWindowIcons() const { return m_showWindowIcons; }
+        void setShowWindowIcons(bool show);
+
+        bool showDesktopName() const { return m_displayedText == Name; }
+        bool showDesktopNumber() const { return m_displayedText == Number; }
+
+        Q_INVOKABLE void moveWindow(int, double, double, int, int);
+        Q_INVOKABLE void changeDesktop(int desktopId);
+        Q_INVOKABLE QPixmap shadowText(const QString& text);
+        Q_INVOKABLE void updateToolTip(int hoverDesktopId);
+
+    signals:
+        void styleChanged();
+        void currentDesktopChanged();
+        void showWindowIconsChanged();
+        void showDesktopTextChanged();
+
     public slots:
         void recalculateGridSizes(int rows);
         void updateSizes(bool allowResize);
@@ -81,57 +91,49 @@ class Pager : public Plasma::Applet
         void configChanged();
 
     protected slots:
-        virtual void mousePressEvent(QGraphicsSceneMouseEvent *event);
-        virtual void mouseMoveEvent(QGraphicsSceneMouseEvent *event);
-        virtual void mouseReleaseEvent(QGraphicsSceneMouseEvent *event);
-        virtual void hoverEnterEvent(QGraphicsSceneHoverEvent *event);
-        virtual void hoverMoveEvent(QGraphicsSceneHoverEvent *event);
-        virtual void hoverLeaveEvent(QGraphicsSceneHoverEvent *event);
-        virtual void dragEnterEvent(QGraphicsSceneDragDropEvent *event);
-        virtual void dragMoveEvent(QGraphicsSceneDragDropEvent *event);
-        virtual void dragLeaveEvent(QGraphicsSceneDragDropEvent *event);
-        virtual void dropEvent(QGraphicsSceneDragDropEvent *event);
         virtual void wheelEvent(QGraphicsSceneWheelEvent *);
 
         void configAccepted();
         void currentDesktopChanged(int desktop);
         void currentActivityChanged(const QString &activity);
         void desktopsSizeChanged();
-        void windowAdded(WId id);
-        void windowRemoved(WId id);
-        void activeWindowChanged(WId id);
         void numberOfDesktopsChanged(int num);
         void desktopNamesChanged();
-        void stackingOrderChanged();
         void windowChanged(WId id, const unsigned long *dirty);
-        void showingDesktopChanged(bool showing);
+        void startTimer();
+        void startTimerFast();
 #ifdef Q_WS_X11
         void slotAddDesktop();
         void slotRemoveDesktop();
 #endif
-        void dragSwitch();
 
     protected:
         void createMenu();
-        KColorScheme *colorScheme();
+        KColorScheme *plasmaColorTheme();
         QRect fixViewportPosition( const QRect& r );
         void createConfigurationInterface(KConfigDialog *parent);
-        void handleHoverMove(const QPointF& pos);
-        void handleHoverLeave();
-        void updateToolTip();
 
     private:
+        void updatePagerStyle();
+        void initDeclarativeUI();
+        QRectF mapToDeclarativeUI(const QRectF &rect) const;
+
+        Plasma::DeclarativeWidget *m_declarativeWidget;
+        PagerModel *m_pagerModel;
+        QVariantMap m_pagerStyle;
+
+        // Used just to get the margins
+        Plasma::FrameSvg *m_dummy;
+
         QTimer* m_timer;
         Ui::pagerConfig ui;
-        enum DisplayedText
-        {
+        enum DisplayedText {
             Number,
             Name,
             None
         };
 
-        enum CurrentDesktopSelected
-        {
+        enum CurrentDesktopSelected {
             DoNothing,
             ShowDesktop,
             ShowDashboard
@@ -140,7 +142,6 @@ class Pager : public Plasma::Applet
         DisplayedText m_displayedText;
         CurrentDesktopSelected m_currentDesktopSelected;
         bool m_showWindowIcons;
-        bool m_showOwnBackground;
         int m_rows;
         int m_columns;
         int m_desktopCount;
@@ -150,37 +151,16 @@ class Pager : public Plasma::Applet
         qreal m_widthScaleFactor;
         qreal m_heightScaleFactor;
         QSizeF m_size;
-        QList<QRectF> m_rects;
+
         //list of info about animations for each desktop
-        QList<DesktopRectangle*> m_animations;
-        QRectF m_hoverRect;
-        int m_hoverIndex;
-        QList<QList<QPair<WId, QRect> > > m_windowRects;
-        QList<QRect> m_activeWindows;
         QList<QAction*> m_actions;
         QAction *m_addDesktopAction;
         QAction *m_removeDesktopAction;
-        QList<KWindowInfo> m_windowInfo;
-        Plasma::FrameSvg *m_background;
-        KColorScheme *m_colorScheme;
+        KColorScheme *m_plasmaColorTheme;
         bool m_verticalFormFactor;
 
-        // dragging of windows
-        QRect m_dragOriginal;
-        QPointF m_dragOriginalPos;
-        QPointF m_dragCurrentPos;
-        WId m_dragId;
-        int m_dragStartDesktop;
-        int m_dragHighlightedDesktop;
-
-        // desktop switching on drop event
-        int m_dragSwitchDesktop;
-        QTimer* m_dragSwitchTimer;
         bool m_ignoreNextSizeConstraint;
 
-        static const int s_FadeInDuration = 50;
-        static const int s_FadeOutDuration = 100;
-
         //embedded KCM module in the configuratoin dialog
         KCModuleProxy *m_configureDesktopsWidget;
 
